"""
Urls for wscounter views
"""

from django.conf.urls import patterns, url

from wscounter import views

urlpatterns = patterns(
    '',
    url(r'^$', views.WSCounterAPIView.as_view(), name='counter_api'),
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from rest_framework.response import Response
from rest_framework.views import APIView
from rest_framework import authentication, permissions
import register

class WSCounterAPIView(APIView):
    authentication_classes = (authentication.CSRFCheck,)
    permission_classes = (permissions.AllowAny,)

    def get(self, request, format=None):
        summary = {}

        for model in register.models:
            summary[model.__name__] = model.objects.all().count()

        return Response(summary)


import os
from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()

setup(
    name='django-wscounter',
    version='0.1.2.4',
    packages=['wscounter'],
    description='A dynamic web-socket',
    long_description=README,
    author='Firas Al Kafri',
    author_email='firas.alkafri@gmail.com',
    url='https://github.com/salalem/django-wscounter/',
    license='GPLv2',
    install_requires=[
        'Django>=1.8',
        'djangorestframework>=3.2.3'
    ]
)
